@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2010-2012 The pygit2 contributors
+# Copyright 2010-2013 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -25,6 +25,30 @@
 # the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 # Boston, MA 02110-1301, USA.
 
-from .version import __version__
+# Import from the future
+from __future__ import absolute_import
+
+# Low level API
+import _pygit2
 from _pygit2 import *
+
+# High level API
+from .repository import Repository
+from .version import __version__
 import pygit2.utils
+
+
+def init_repository(path, bare=False):
+    """
+    Creates a new Git repository in the given path.
+
+    Arguments:
+
+    path
+      Path where to create the repository.
+
+    bare
+      Whether the repository will be bare or not.
+    """
+    _pygit2.init_repository(path, bare)
+    return Repository(path)
