@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2012 The pygit2 contributors
+# Copyright 2010-2013 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -30,8 +30,6 @@
 from __future__ import absolute_import
 from __future__ import unicode_literals
 import unittest
-import tempfile
-import os
 
 import pygit2
 from . import utils
