@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2012 The pygit2 contributors
+# Copyright 2010-2013 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -39,6 +39,7 @@ config_filename = "test_config"
 def foreach_test_wrapper(key, name, lst):
     lst[key] = name
     return 0
+foreach_test_wrapper.__test__ = False
 
 class ConfigTest(utils.RepoTestCase):
 
@@ -54,16 +55,17 @@ class ConfigTest(utils.RepoTestCase):
     def test_global_config(self):
         try:
             self.assertNotEqual(None, pygit2.Config.get_global_config())
-        except IOError:
+        except IOError: # there is no user config
             pass
 
     def test_system_config(self):
         try:
             self.assertNotEqual(None, pygit2.Config.get_system_config())
-        except IOError:
+        except IOError:  # there is no system config
             pass
 
     def test_new(self):
+        open(config_filename, 'w').close() # touch file
         config_write = pygit2.Config(config_filename)
 
         self.assertNotEqual(config_write, None)
@@ -96,9 +98,10 @@ class ConfigTest(utils.RepoTestCase):
 
         self.assertRaises(TypeError, lambda: config[()])
         self.assertRaises(TypeError, lambda: config[-4])
-        self.assertRaisesWithArg(pygit2.GitError,
-                "Invalid variable name: 'abc'", lambda: config['abc'])
-        self.assertRaisesWithArg(KeyError, 'abc.def', lambda: config['abc.def'])
+        self.assertRaisesWithArg(ValueError, "Invalid config item name 'abc'",
+                                 lambda: config['abc'])
+        self.assertRaisesWithArg(KeyError, 'abc.def',
+                                 lambda: config['abc.def'])
 
         self.assertTrue('core.bare' in config)
         self.assertFalse(config['core.bare'])
@@ -115,7 +118,7 @@ class ConfigTest(utils.RepoTestCase):
         self.assertTrue('this.that' in config)
         self.assertEqual(len(config.get_multivar('this.that')), 2)
         l = config.get_multivar('this.that', 'bar')
-        self.assertEqual(len(l),1)
+        self.assertEqual(len(l), 1)
         self.assertEqual(l[0], 'foobar')
 
     def test_write(self):
@@ -150,16 +153,21 @@ class ConfigTest(utils.RepoTestCase):
         new_file.write("[this]\n\tthat = foobar\n\tthat = foobeer\n")
         new_file.close()
 
-        config.add_file(config_filename, 0)
+        config.add_file(config_filename, 5)
         self.assertTrue('this.that' in config)
+        l = config.get_multivar('this.that', 'foo.*')
+        self.assertEqual(len(l), 2)
+
         config.set_multivar('this.that', '^.*beer', 'fool')
         l = config.get_multivar('this.that', 'fool')
-        self.assertEqual(len(l),1)
+        self.assertEqual(len(l), 1)
         self.assertEqual(l[0], 'fool')
-        config.set_multivar('this.that', 'foo.*', '123456')
+
+        config.set_multivar('this.that', 'foo.*', 'foo-123456')
         l = config.get_multivar('this.that', 'foo.*')
+        self.assertEqual(len(l), 2)
         for i in l:
-            self.assertEqual(i, '123456')
+            self.assertEqual(i, 'foo-123456')
 
     def test_foreach(self):
         config = self.repo.config
