@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2012 The pygit2 contributors
+# Copyright 2010-2013 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -30,15 +30,21 @@
 from __future__ import absolute_import
 from __future__ import unicode_literals
 import unittest
-
+import pygit2
+from pygit2 import GIT_DIFF_INCLUDE_UNMODIFIED
 from . import utils
 
 
 COMMIT_SHA1_1 = '5fe808e8953c12735680c257f56600cb0de44b10'
 COMMIT_SHA1_2 = 'c2792cfa289ae6321ecf2cd5806c2194b0fd070c'
 COMMIT_SHA1_3 = '2cdae28389c059815e951d0bb9eed6533f61a46b'
+COMMIT_SHA1_4 = 'ccca47fbb26183e71a7a46d165299b84e2e6c0b3'
+COMMIT_SHA1_5 = '056e626e51b1fc1ee2182800e399ed8d84c8f082'
+COMMIT_SHA1_6 = 'f5e5aa4e36ab0fe62ee1ccc6eb8f79b866863b87'
+COMMIT_SHA1_7 = '784855caf26449a1914d2cf62d12b9374d76ae78'
 
-PATCH = b"""diff --git a/a b/a
+
+PATCH = """diff --git a/a b/a
 index 7f129fd..af431f2 100644
 --- a/a
 +++ b/a
@@ -55,35 +61,40 @@ index 297efb8..0000000
 """
 
 DIFF_INDEX_EXPECTED = [
-  'staged_changes',
-  'staged_changes_file_deleted',
-  'staged_changes_file_modified',
-  'staged_delete',
-  'staged_delete_file_modified',
-  'staged_new',
-  'staged_new_file_deleted',
-  'staged_new_file_modified'
+    'staged_changes',
+    'staged_changes_file_deleted',
+    'staged_changes_file_modified',
+    'staged_delete',
+    'staged_delete_file_modified',
+    'staged_new',
+    'staged_new_file_deleted',
+    'staged_new_file_modified'
 ]
 
 DIFF_WORKDIR_EXPECTED = [
-  'file_deleted',
-  'modified_file',
-  'staged_changes',
-  'staged_changes_file_deleted',
-  'staged_changes_file_modified',
-  'staged_delete',
-  'staged_delete_file_modified',
-  'subdir/deleted_file',
-  'subdir/modified_file'
+    'file_deleted',
+    'modified_file',
+    'staged_changes',
+    'staged_changes_file_deleted',
+    'staged_changes_file_modified',
+    'staged_delete',
+    'staged_delete_file_modified',
+    'subdir/deleted_file',
+    'subdir/modified_file'
 ]
 
+HUNK_EXPECTED = """@@ -1 +1 @@
+a contents 2
+a contents
+"""
+
 class DiffDirtyTest(utils.DirtyRepoTestCase):
     def test_diff_empty_index(self):
         repo = self.repo
         head = repo[repo.lookup_reference('HEAD').resolve().oid]
         diff = head.tree.diff(repo.index)
 
-        files = [x[1] for x in diff.changes['files']]
+        files = [patch.new_file_path for patch in diff]
         self.assertEqual(DIFF_INDEX_EXPECTED, files)
 
     def test_workdir_to_tree(self):
@@ -91,7 +102,7 @@ class DiffDirtyTest(utils.DirtyRepoTestCase):
         head = repo[repo.lookup_reference('HEAD').resolve().oid]
         diff = head.tree.diff()
 
-        files = [x[1] for x in diff.changes['files']]
+        files = [patch.new_file_path for patch in diff]
         self.assertEqual(DIFF_WORKDIR_EXPECTED, files)
 
 class DiffTest(utils.BareRepoTestCase):
@@ -106,7 +117,7 @@ class DiffTest(utils.BareRepoTestCase):
         head = repo[repo.lookup_reference('HEAD').resolve().oid]
         diff = head.tree.diff(repo.index)
 
-        files = [x[0].split('/')[0] for x in diff.changes['files']]
+        files = [patch.new_file_path.split('/')[0] for patch in diff]
         self.assertEqual([x.name for x in head.tree], files)
 
     def test_diff_tree(self):
@@ -118,20 +129,31 @@ class DiffTest(utils.BareRepoTestCase):
         # self.assertIsNotNone is 2.7 only
         self.assertTrue(diff is not None)
         # self.assertIn is 2.7 only
-        self.assertTrue(('a','a', 3) in diff.changes['files'])
-        self.assertEqual(2, len(diff.changes['hunks']))
+        self.assertEqual(2, sum(map(lambda x: len(x.hunks), diff)))
 
-        hunk = diff.changes['hunks'][0]
+        patch = diff[0]
+        hunk = patch.hunks[0]
         self.assertEqual(hunk.old_start, 1)
-        self.assertEqual(hunk.old_lines, 0)
+        self.assertEqual(hunk.old_lines, 1)
         self.assertEqual(hunk.new_start, 1)
-        self.assertEqual(hunk.new_lines, 0)
+        self.assertEqual(hunk.new_lines, 1)
 
-        self.assertEqual(hunk.old_file, 'a')
-        self.assertEqual(hunk.new_file, 'a')
+        self.assertEqual(patch.old_file_path, 'a')
+        self.assertEqual(patch.new_file_path, 'a')
 
-        #self.assertEqual(hunk.data[0][0], b'a contents 2\n')
-        #self.assertEqual(hunk.data[1][0], b'a contents\n')
+    def test_diff_tree_opts(self):
+        commit_c = self.repo[COMMIT_SHA1_3]
+        commit_d = self.repo[COMMIT_SHA1_4]
+
+        for opt in [pygit2.GIT_DIFF_IGNORE_WHITESPACE,
+                    pygit2.GIT_DIFF_IGNORE_WHITESPACE_EOL]:
+            diff = commit_c.tree.diff(commit_d.tree, opt)
+            self.assertTrue(diff is not None)
+            self.assertEqual(0, len(diff[0].hunks))
+
+        diff = commit_c.tree.diff(commit_d.tree)
+        self.assertTrue(diff is not None)
+        self.assertEqual(1, len(diff[0].hunks))
 
     def test_diff_merge(self):
         commit_a = self.repo[COMMIT_SHA1_1]
@@ -147,25 +169,23 @@ class DiffTest(utils.BareRepoTestCase):
         self.assertTrue(diff_c is not None)
 
         # assertIn / assertNotIn are 2.7 only
-        self.assertTrue(('b','b', 3) not in diff_b.changes['files'])
-        self.assertTrue(('b','b', 3) in diff_c.changes['files'])
+        self.assertFalse('b' in [patch.new_file_path for patch in diff_b])
+        self.assertTrue('b' in [patch.new_file_path for patch in diff_c])
 
         diff_b.merge(diff_c)
 
         # assertIn is 2.7 only
-        self.assertTrue(('b','b', 3) in diff_b.changes['files'])
+        self.assertTrue('b' in [patch.new_file_path for patch in diff_b])
 
-        hunk = diff_b.changes['hunks'][1]
+        patch = diff_b[0]
+        hunk = patch.hunks[0]
         self.assertEqual(hunk.old_start, 1)
-        self.assertEqual(hunk.old_lines, 0)
+        self.assertEqual(hunk.old_lines, 1)
         self.assertEqual(hunk.new_start, 1)
-        self.assertEqual(hunk.new_lines, 0)
+        self.assertEqual(hunk.new_lines, 1)
 
-        self.assertEqual(hunk.old_file, 'b')
-        self.assertEqual(hunk.new_file, 'b')
-
-        #self.assertEqual(hunk.data[0][0], b'b contents\n')
-        #self.assertEqual(hunk.data[1][0], b'b contents 2\n')
+        self.assertEqual(patch.old_file_path, 'a')
+        self.assertEqual(patch.new_file_path, 'a')
 
     def test_diff_patch(self):
         commit_a = self.repo[COMMIT_SHA1_1]
@@ -174,19 +194,32 @@ class DiffTest(utils.BareRepoTestCase):
         diff = commit_a.tree.diff(commit_b.tree)
         self.assertEqual(diff.patch, PATCH)
 
-    def test_diff_header(self):
-        commit_a = self.repo[COMMIT_SHA1_1]
-        commit_b = self.repo[COMMIT_SHA1_2]
-        diff = commit_a.tree.diff(commit_b.tree)
-
-        self.assertEqual(diff.changes['hunks'][0].header, "@@ -1 +1 @@\n")
-
     def test_diff_oids(self):
         commit_a = self.repo[COMMIT_SHA1_1]
         commit_b = self.repo[COMMIT_SHA1_2]
-        diff = commit_a.tree.diff(commit_b.tree)
-        self.assertEqual(diff.changes['hunks'][0].old_oid, '7f129fd57e31e935c6d60a0c794efe4e6927664b')
-        self.assertEqual(diff.changes['hunks'][0].new_oid, 'af431f20fc541ed6d5afede3e2dc7160f6f01f16')
+        patch = commit_a.tree.diff(commit_b.tree)[0]
+        self.assertEqual(patch.old_oid,
+                         '7f129fd57e31e935c6d60a0c794efe4e6927664b')
+        self.assertEqual(patch.new_oid,
+                         'af431f20fc541ed6d5afede3e2dc7160f6f01f16')
+
+    def test_hunk_content(self):
+        commit_a = self.repo[COMMIT_SHA1_1]
+        commit_b = self.repo[COMMIT_SHA1_2]
+        patch = commit_a.tree.diff(commit_b.tree)[0]
+        hunk = patch.hunks[0]
+        self.assertEqual(HUNK_EXPECTED, ''.join(hunk.lines))
+
+    def test_find_similar(self):
+        commit_a = self.repo[COMMIT_SHA1_6]
+        commit_b = self.repo[COMMIT_SHA1_7]
+
+        #~ Must pass GIT_DIFF_INCLUDE_UNMODIFIED if you expect to emulate
+        #~ --find-copies-harder during rename transformion...
+        diff = commit_a.tree.diff(commit_b.tree, GIT_DIFF_INCLUDE_UNMODIFIED)
+        self.assertAll(lambda x: x.status is not pygit2.GIT_DELTA_RENAMED, diff)
+        diff.find_similar()
+        self.assertAny(lambda x: x.status is pygit2.GIT_DELTA_RENAMED, diff)
 
 if __name__ == '__main__':
     unittest.main()
