@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2011 Itaapy
+# Copyright 2010-2013 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -36,9 +36,6 @@ import pygit2
 from . import utils
 
 
-__author__ = 'jdavid@itaapy.com (J. David Ibáñez)'
-
-
 class IndexBareTest(utils.BareRepoTestCase):
 
     def test_bare(self):
@@ -83,7 +80,7 @@ class IndexTest(utils.RepoTestCase):
 
     def test_write(self):
         index = self.repo.index
-        index.add('bye.txt', 0)
+        index.add('bye.txt')
         index.write()
 
         index.clear()
@@ -136,7 +133,15 @@ class IndexTest(utils.RepoTestCase):
         self.assertEqual([x.hex for x in index],
                 [x.hex for x in self.repo.index])
 
-        self.assertRaises(pygit2.GitError, lambda: index.add('bye.txt', 0))
+        self.assertRaises(pygit2.GitError, lambda: index.add('bye.txt'))
+
+    def test_del(self):
+        index = self.repo.index
+        del index['hello.txt']
+
+    def test_remove(self):
+        index = self.repo.index
+        index.remove('hello.txt')
 
 if __name__ == '__main__':
     unittest.main()
