@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2011 Itaapy
+# Copyright 2010-2013 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -35,8 +35,6 @@ from pygit2 import GitError, GIT_REF_OID, GIT_REF_SYMBOLIC
 from . import utils
 
 
-__author__ = 'david.versmisse@itaapy.com (David Versmisse)'
-
 LAST_COMMIT = '2be5719152d4f82c7302b1c0932d8e5f0a4a0e98'
 
 
@@ -51,8 +49,8 @@ class ReferencesTest(utils.RepoTestCase):
                          ['refs/heads/i18n', 'refs/heads/master'])
 
         # We add a symbolic reference
-        reference = repo.create_symbolic_reference('refs/tags/version1',
-                                                   'refs/heads/master')
+        repo.create_reference('refs/tags/version1', 'refs/heads/master',
+                              symbolic=True)
         self.assertEqual(sorted(repo.listall_references()),
                          ['refs/heads/i18n', 'refs/heads/master',
                           'refs/tags/version1'])
@@ -61,12 +59,15 @@ class ReferencesTest(utils.RepoTestCase):
         self.assertEqual(repo.listall_references(GIT_REF_SYMBOLIC),
                          ('refs/tags/version1', ))
 
+    def test_head(self):
+        head = self.repo.head
+        self.assertEqual(LAST_COMMIT, self.repo[head.oid].hex)
 
     def test_lookup_reference(self):
         repo = self.repo
 
         # Raise KeyError ?
-        self.assertRaises(KeyError, repo.lookup_reference, 'foo')
+        self.assertRaises(KeyError, repo.lookup_reference, 'refs/foo')
 
         # Test a lookup
         reference = repo.lookup_reference('refs/heads/master')
@@ -141,15 +142,16 @@ class ReferencesTest(utils.RepoTestCase):
         self.assertEqual(reference.name, 'refs/tags/version2')
 
 
-    def test_reload(self):
-        name = 'refs/tags/version1'
+#   def test_reload(self):
+#       name = 'refs/tags/version1'
 
-        ref = self.repo.create_symbolic_reference(name, "refs/heads/master")
-        ref2 = self.repo.lookup_reference(name)
-        ref.delete()
-        self.assertEqual(ref2.name, name)
-        self.assertRaises(KeyError, ref2.reload)
-        self.assertRaises(GitError, getattr, ref2, 'name')
+#       repo = self.repo
+#       ref = repo.create_reference(name, "refs/heads/master", symbolic=True)
+#       ref2 = repo.lookup_reference(name)
+#       ref.delete()
+#       self.assertEqual(ref2.name, name)
+#       self.assertRaises(KeyError, ref2.reload)
+#       self.assertRaises(GitError, getattr, ref2, 'name')
 
 
     def test_reference_resolve(self):
@@ -174,19 +176,41 @@ class ReferencesTest(utils.RepoTestCase):
         self.assertTrue('refs/tags/version1' in refs)
         reference = self.repo.lookup_reference('refs/tags/version1')
         self.assertEqual(reference.hex, LAST_COMMIT)
+        self.assertEqual(reference.target, LAST_COMMIT)
+
+        # try to create existing reference
+        self.assertRaises(ValueError, self.repo.create_reference,
+                          'refs/tags/version1', LAST_COMMIT)
+
+        # try to create existing reference with force
+        reference =  self.repo.create_reference('refs/tags/version1',
+                        LAST_COMMIT, force=True)
+        self.assertEqual(reference.hex, LAST_COMMIT)
 
 
     def test_create_symbolic_reference(self):
         # We add a tag as a new symbolic reference that always points to
         # "refs/heads/master"
-        reference = self.repo.create_symbolic_reference('refs/tags/beta',
-                                                        'refs/heads/master')
+        reference = self.repo.create_reference('refs/tags/beta',
+                        'refs/heads/master', symbolic=True)
         self.assertEqual(reference.type, GIT_REF_SYMBOLIC)
         self.assertEqual(reference.target, 'refs/heads/master')
 
 
-    def test_packall_references(self):
-        self.repo.packall_references()
+        # try to create existing symbolic reference
+        self.assertRaises(ValueError, self.repo.create_reference,
+                          'refs/tags/beta', 'refs/heads/master',
+                          symbolic=True)
+
+        # try to create existing symbolic reference with force
+        reference =  self.repo.create_reference('refs/tags/beta',
+                        'refs/heads/master', force=True, symbolic=True)
+        self.assertEqual(reference.type, GIT_REF_SYMBOLIC)
+        self.assertEqual(reference.target, 'refs/heads/master')
+
+
+#   def test_packall_references(self):
+#       self.repo.packall_references()
 
 
 if __name__ == '__main__':
