@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012 Carlos Martín Nieto
+# Copyright 2010-2013 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -29,20 +29,17 @@
 
 from __future__ import absolute_import
 from __future__ import unicode_literals
-import os
 import unittest
 
-import pygit2
 from . import utils
 
 
-__author__ = 'carlos@cmartin.tk (Carlos Martín Nieto)'
-
 TREE_SHA = '967fce8df97cc71722d3c2a5930ef3e6f1d27b12'
 
 class TreeBuilderTest(utils.BareRepoTestCase):
+
     def test_new_empty_treebuilder(self):
-        bld = self.repo.TreeBuilder()
+        self.repo.TreeBuilder()
 
     def test_noop_treebuilder(self):
         tree = self.repo[TREE_SHA]
@@ -60,10 +57,11 @@ class TreeBuilderTest(utils.BareRepoTestCase):
         tree = self.repo[TREE_SHA]
         bld = self.repo.TreeBuilder()
         for e in tree:
-            bld.insert(e.name, e.hex, e.attributes)
+            bld.insert(e.name, e.hex, e.filemode)
 
         result = bld.write()
         self.assertEqual(tree.oid, result)
 
+
 if __name__ == '__main__':
     unittest.main()
